@@ -3,19 +3,31 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.08_01';
+our $VERSION = '0.09_03';
 
 use Carp;
 use Exporter;
+use File::Temp qw(tempfile);
 
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw (pread pwrite);
+our @EXPORT_OK = qw (read pread write pwrite);
 
 sub new {
     return bless {}, shift;
 }
 sub read {
 
+    if (ref($_[0]) ne 'File::Edit::Portable'){
+        if (wantarray){
+            my @ret = pread(@_);
+            return @ret;
+        }
+        else {
+            my $fh = pread(@_);
+            return $fh;
+        }
+    }
+            
     my $self = shift;
 
     $self->_config(@_);
@@ -52,6 +64,11 @@ sub read {
 }
 sub write {
 
+    if (ref($_[0]) ne 'File::Edit::Portable'){
+        pwrite(@_);
+        return 1;
+    }
+
     my $self = shift;
     my $p = $self->_config(@_);
 
@@ -98,22 +115,19 @@ sub recsep {
     my $self = shift;
     my $file = shift;
 
-    open my $fh, '<', $file 
-      or croak "recsep() can't open file $file!: $!";
+    my $fh = $self->_open($file);
 
     binmode $fh, ':raw';
 
-    my @contents = <$fh>;
+    return if ! <$fh>;
 
-    close $fh or croak "recsep() can't close file $file!: $!";
-
-    return if ! $contents[0];
-
-    if ($contents[0] =~ /(\R)/){
+    if (<$fh> =~ /(\R)/){
         $self->{recsep} = $1;
         $ENV{FEP_RECSEP} = $1;
     }
 
+    close $fh or croak "recsep() can't close file $file!: $!";
+    
     my $recsep = unpack "H*", $self->{recsep};
 
     $recsep =~ s/0/\\0/g;
@@ -123,29 +137,33 @@ sub recsep {
 sub platform_recsep {
 
     my $self = shift;
-    my $file = 'local.tmp';
 
-    open my $wfh, '>', $file 
-      or die "platform_recsep() can't open temp file $!";
+    my $file = $self->_temp_file;
 
-    print $wfh "x\n";
+    # this is for checking to see if we've cleaned up
+    # in DESTROY
 
-    close $wfh or die "platform_recsep() can't close temp file $!";
+    push @{ $self->{temp_files} }, $file;
 
-    open my $fh, '<', $file 
-      or die "platform_recsep() can't open temp file $!";
+    # for platform_recsep(), we need the file open in ASCII mode,
+    # so we can't use _open() or File::Temp
 
-    binmode $fh, ':raw';
+    open my $wfh, '>', $file
+      or die "platform_recsep() can't open temp file $file for writing!: $!";
 
-    for (<$fh>){
-        if (/(\R)/){
-            $self->{platform_recsep} = $1;
-        }
+    print $wfh "abc\n";
+
+    close $wfh
+      or croak "platform_recsep() can't close temp file $file write: $!";
+
+    my $fh = $self->_open($file);
+
+    if (<$fh> =~ /(\R)/){
+        $self->{platform_recsep} = $1;
     }
 
-    close $fh or die "platform_recsep() can't close temp file $!";
-
-    unlink $file or die "platform_recsep() can't unlink the 'local.txt' temp file";
+    close $fh
+      or croak "platform_recsep() can't close temp file $file after run: $!";
 
     return $self->{platform_recsep};
 }
@@ -162,15 +180,15 @@ sub pread {
 
     $rw->recsep($file);
 
-    my $fh = $rw->_open($file);
-
     if (! wantarray){
         my $handle = $rw->_handle($file);
         return $handle;
     }
     else {
 
+        my $fh = $rw->_open($file);
         my @contents = <$fh>;
+        
         close $fh or croak "read() can't close file $file!: $!";
 
         if (! $testing){
@@ -235,26 +253,29 @@ sub _handle {
     my $self = shift;
     my $file = shift;
 
-    my $temp_file = "$$.tmp";
-
     my $fh = $self->_open($file);
-    binmode $fh, ':raw';
+    my $temp_wfh = File::Temp->new(UNLINK => 1);
+    binmode $temp_wfh, ':raw';
+    
+    my $temp_filename = $temp_wfh->filename;
 
-    my $wfh = $self->_open($temp_file, 'w');
-    binmode $wfh, ':raw';
+    # we'll check these in DESTROY to make sure we've
+    # cleaned up appropriately
+
+    push @{ $self->{temp_files} }, $temp_filename;
 
     $self->platform_recsep;
 
     for (<$fh>){
         s/\R/$self->{platform_recsep}/;
-        print $wfh $_;
+        print $temp_wfh $_;
     }
 
     close $fh or die "can't close file $file: $!";
-    close $wfh or die "can't close file $file: $!";
-
-    my $ret_fh = $self->_open($temp_file);
+    close $temp_wfh or die "can't close file $temp_filename: $!";
 
+    my $ret_fh = $self->_open($temp_filename);
+    
     return $ret_fh;
 }
 sub _open {
@@ -278,11 +299,30 @@ sub _open {
 
     return $fh;
 }
+sub _temp_file {
+
+    my $self = shift;
+    
+    my $temp_fh = File::Temp->new(UNLINK => 1);
+
+    my $file = $temp_fh->filename;
+
+    close $temp_fh
+     or croak "_temp_file() can't close the $file temp file: $!";
+
+    return $file;
+}
 sub DESTROY {
-    if (-f "$$.tmp"){
-        eval { unlink "$$.tmp" or die $!; };
-        if ($@){
-            croak "can't unlink temp file $$.txt in DESTROY()";
+    
+    my $self = shift;
+
+    for (@{ $self->{temp_files} }){
+        if (-f && $^O ne 'MSWin32'){
+            eval { unlink $_ or die $!; };
+            if ($@){
+                croak "File::Temp didn't unlink $_ temp file, and we " .
+                      "can't unlink it in our DESTROY() either!: $@";
+            }
         }
     }
 }
@@ -330,12 +370,17 @@ Get the local platforms record separator. This will be in string representation.
 
 There's also a non-OO interface...
 
-    use File::Edit::Portable qw(pread pwrite);
+    use File::Edit::Portable qw(read write);
 
-    my $fh = pread('file.txt');
-    my @contents = pread('file.txt');
+    my $fh = read('file.txt');
 
-    pwrite('file.txt', \@contents);
+    # and/or
+
+    my @contents = read('file.txt');
+
+    # then
+
+    write('file.txt', \@contents);
 
 
 =head1 DESCRIPTION
@@ -346,14 +391,15 @@ This module will read in a file, keep track of the file's current record separat
 
 Uses are for dynamically reading/writing files while on one Operating System, but you don't know whether the record separators are platform-standard. Shared storage between multpile platforms are a good use case. This module affords you the ability to not have to check each file, and is very useful in looping over a directory where various files may have been written by different platforms.
 
-=head1 EXPORTS
-    None by default. See L<EXPORT_OK>
+=head1 EXPORT
+
+None by default. See L<EXPORT_OK>
 
 =head1 EXPORT_OK
 
 If you desire using the non-OO functionality, the following functions are exported on demand.
 
-    C<pread()> and C<pwrite()>
+C<read()> and C<write()>. If there are namespace collisions with those two functions, C<pread()> and C<pwrite()> are available as well.
 
 =head1 METHODS
 
@@ -397,13 +443,17 @@ Returns the string representation of the current platform's (OS) record separato
 
 =head1 FUNCTIONS
 
-=head2 C<pread('file.txt')>
+=head2 C<read('file.txt')>
+
+C<pread()> can alternately be imported in the event of namespace collisions.
 
 In scalar context, will return a read-only file handle. In list context, returns an array with each element being a line in the file, with the endings stripped off.
 
-=head2 C<pwrite('file.txt', \@contents, 'copy.txt', "\r\n")>
+=head2 C<write('file.txt', \@contents, 'copy.txt', "\r\n")>
 
-Writes back out the file (or alternately a new file (copy.txt), using the original file's line endings, or optionally a custom record separator as specified by the last parameter.
+C<pwrite()> can alternately be imported in the event of namespace collisions.
+
+Writes back out the file (or alternately a new file (copy.txt), using the original file's line endings, or optionally a custom record separator as specified by the last parameter. Note the record separator MUST be sent in within double-quotes.
 
 If you want to send in a custom record separator but not use a copy file, just set the third parameter (copy.txt) to C<undef> within the call.
 
@@ -418,6 +468,15 @@ Please report any bugs or feature requests to C<bug-file-edit-portable at rt.cpa
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Edit-Portable>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+=head1 REPOSITORY
+
+L<https://github.com/stevieb9/file-edit-portable>
+
+=head1 BUILD RESULTS
+
+Travis-CI: L<https://travis-ci.org/stevieb9/file-edit-portable>
+
+CPAN Testers: L<http://matrix.cpantesters.org/?dist=File-Edit-Portable>
 
 =head1 SUPPORT
 
